@@ -3,7 +3,8 @@ from itertools import combinations
 from pyscf import gto, scf, symm, tools, ao2mo
 from openfermion import QubitOperator, FermionOperator, jordan_wigner, utils, linalg
 from qiskit import opflow, quantum_info
-from qiskit_nature.operators.second_quantization import SecondQuantizedOp, FermionicOp
+from qiskit_nature.operators.second_quantization import FermionicOp
+from qiskit_nature.converters.second_quantization import QubitConverter
 from qiskit_nature.mappers.second_quantization import JordanWignerMapper
 from IPython.display import display, HTML
 from tabulate import tabulate
@@ -733,9 +734,9 @@ def QubitOperator_to_PauliSumOp(qubitoperator):
         output += qubitoperator.terms[key]*quantum_info.SparsePauliOp(string)
     return opflow.PauliSumOp(output).reduce()
 
-def PauliSumOp_to_QubitOperator():
+def PauliSumOp_to_QubitOperator(input):
     output = QubitOperator()
-    for k in x:
+    for k in input:
         k = str(k.to_pauli_op())
         N = len(k)
         term = str()
@@ -850,11 +851,11 @@ def make_encoding(atom, basis, charge = 0, spin = 0, irrep = None):
     encoding = (tableau, tableau_signs, target_qubits)
     return encoding
 
-def apply_encoding(operator, encoding):
+def apply_encoding(operator, encoding, output_format = 'openfermion'):
     """Applies the encoding to a fermionic operator object or a qubit operator (in the Jordan Wigner basis) object
 
     Args:
-        operator (openfermion.QubitOperator or openfermion.FermionOperator): a fermionic operator object or a qubit operator (in the Jordan Wigner basis) object in OpenFermion
+        operator (Qiskit FermionicOp or OpenFermion QubitOperator or OpenFermion FermionOperator): a fermionic operator object or a qubit operator (in the Jordan Wigner basis) object in OpenFermion
         encoding (tuple): an encoding object
 
     Returns:
@@ -862,16 +863,18 @@ def apply_encoding(operator, encoding):
     """
     if type(operator) == FermionOperator:
         operator = jordan_wigner(operator)
-    if type(operator) == SecondQuantizedOp:
-        operator = JordanWignerMapper.map(operator)
     if type(operator) == FermionicOp:
-        operator = JordanWignerMapper.map(operator)
+        operator = QubitConverter(JordanWignerMapper()).convert(operator)
     if type(operator) == opflow.PauliSumOp:
         operator = PauliSumOp_to_QubitOperator(operator)
     tableau, tableau_signs, target_qubits = encoding
     transformed_operator = apply_Clifford_tableau(operator, tableau, tableau_signs)
     reduced_operator = simplify_QubitOperator(project_operator(transformed_operator, target_qubits))
-    return reduced_operator
+    if output_format == 'openfermion':
+        return reduced_operator
+    elif output_format == 'qiskit':
+        reduced_operator = QubitOperator_to_PauliSumOp(reduced_operator)
+        return reduced_operator
 
 def reduced_hamiltonian(atom, basis, charge = 0, spin = 0, irrep = None, verbose = True, show_lowest_eigenvalue = False, output_format = 'openfermion'):
     """Calculates the qubit representation of the second-quantized molecular Hamiltonian in an encoding that reduces its qubit count by using the point-group and parity of number of electron symmetries.
